@@ -44,7 +44,6 @@
 #' @param ... arguments for \code{\link{fromJSON}} and \code{\link{toJSON}} that
 #' control JSON formatting/parsing where applicable. Use with caution.
 #' @name stream_in, stream_out
-#' @aliases stream_in stream_out
 #' @export stream_in stream_out
 #' @rdname stream_in
 #' @references MongoDB export format: \url{http://docs.mongodb.org/manual/reference/program/mongoexport/#cmdoption--query}
@@ -207,7 +206,7 @@ stream_out <- function(x, con = stdout(), pagesize = 500, verbose = TRUE, ...) {
     })
   }
 
-  apply_by_pages(x, stream_out_page, pagesize = pagesize, con = con, verbose = verbose, ...);
+  invisible(apply_by_pages(x, stream_out_page, pagesize = pagesize, con = con, verbose = verbose, ...));
 }
 
 stream_out_page <- function(page, con, ...){
